import React, { useState, useEffect } from 'react';

import Select from 'react-select';

import { useHistory, Link, useParams } from 'react-router-dom';

import Slack from '../../assets/images/table/slack.svg';
import Email from '../../assets/images/alerts/email.svg';
import Edit from '../../assets/images/disable-edit.svg';

import './eventalertdestinationform.scss';

import { CustomContent, CustomActions } from '../../utils/toast-helper';
import { useToast } from 'react-toast-wnm';
import { EMAIL_REGEX } from '../../utils/regex-helper';
import {
  getChannelStatus,
  createKpiAlert,
  updateKpiAlert
} from '../../redux/actions';

import store from '../../redux/store';

import TagsInput from 'react-tagsinput';

import 'react-tagsinput/react-tagsinput.css';

import { useDispatch, useSelector } from 'react-redux';

const RESET_ACTION = {
  type: 'RESET_ALERT_DATA_Data'
};

const customSingleValue = ({ data }) => (
  <div className="input-select">
    <div className="input-select__single-value">
      {data.icon && <span className="input-select__icon">{data.icon}</span>}
      <span>{data.label}</span>
    </div>
  </div>
);

const getOption = (channel) => {
  return {
    label: (
      <div className="optionlabel">
        <img src={channel === 'email' ? Email : Slack} alt="datasource" />
        {channel}
      </div>
    ),
    value: channel
  };
};

const EventAlertDestinationForm = ({
  setEventSteps,
  alertFormData,
  setAlertFormData,
  kpiAlertMetaInfo
}) => {
  const history = useHistory();
  const dispatch = useDispatch();
  const kpiId = useParams().id;
  const toast = useToast();

  const path = history.location.pathname.split('/');

  const {
    createKpiAlertLoading,
    updateKpiAlertLoading,
    channelStatusData,
    createKpiAlertData,
    updateKpiAlertData
  } = useSelector((state) => {
    return state.alert;
  });

  const [resp, setresp] = useState([]);
  const [option, setOption] = useState([]);
  const [field, setField] = useState('');
  const [channelName, setChannelName] = useState('');

  const [error, setError] = useState({
    alert_channel: '',
    add_recepients: ''
  });

  const [enabled, setEnabled] = useState({
    alert_channel: true,
    add_recepients: true
  });

  const [sensitiveData, setSensitveData] = useState({
    alert_channel: '',
    add_recepients: ''
  });

  const onBack = () => {
    store.dispatch(RESET_ACTION);
    setEventSteps(1);
  };

  useEffect(() => {
    dispatch(getChannelStatus());
  }, [dispatch]);

  useEffect(() => {
    if (path[2] === 'edit') {
      setField(alertFormData?.alert_channel);

      if (alertFormData?.alert_channel === 'email') {
        setresp(
          alertFormData?.alert_channel_conf?.[alertFormData.alert_channel] || []
        );
      }
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  useEffect(() => {
    if (channelStatusData && channelStatusData.length !== 0) {
      setOption(
        channelStatusData.map((channel) => {
          return getOption(channel.name);
        })
      );
    }
    channelStatusData.forEach((data) => {
      if (data.name === 'slack') {
        setChannelName(data?.config_setting.channel_name || '');
      }
    });
  }, [channelStatusData]);

  useEffect(() => {
    if (createKpiAlertData && createKpiAlertData.status === 'success') {
      history.push('/alerts');
      customToast({
        type: 'success',
        header: 'Successfully created'
      });
    } else if (createKpiAlertData && createKpiAlertData.status === 'failure') {
      customToast({
        type: 'error',
        header: 'Failed to create KPI',
        description: createKpiAlertData.message
      });
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [createKpiAlertData]);

  useEffect(() => {
    if (updateKpiAlertData && updateKpiAlertData.status === 'success') {
      customToast({
        type: 'success',
        header: 'Successfully updated'
      });
    } else if (updateKpiAlertData && updateKpiAlertData.status === 'failure') {
      customToast({
        type: 'error',
        header: 'Failed to update selected alert',
        description: updateKpiAlertData.message
      });
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [updateKpiAlertData]);

  const customToast = (data) => {
    const { type, header, description } = data;
    toast({
      autoDismiss: true,
      enableAnimation: true,
      delay: type === 'success' ? '5000' : '60000',
      backgroundColor: type === 'success' ? '#effaf5' : '#FEF6F5',
      borderRadius: '6px',
      color: '#222222',
      position: 'bottom-right',
      minWidth: '240px',
      width: 'auto',
      boxShadow: '4px 6px 32px -2px rgba(226, 226, 234, 0.24)',
      padding: '17px 14px',
      height: 'auto',
      border: type === 'success' ? '1px solid #60ca9a' : '1px solid #FEF6F5',
      type: type,
      actions: <CustomActions />,
      content: (
        <CustomContent
          header={header}
          description={description}
          failed={type === 'success' ? false : true}
        />
      )
    });
  };

  const handleChange = (tags) => {
    if (field === 'email') {
      setresp(tags);
      setAlertFormData((prev) => {
        return {
          ...prev,
          alert_channel_conf: {
            [alertFormData['alert_channel']]: tags
          }
        };
      });
    }
  };

  const onSubmit = () => {
    var obj = { ...error };
    if (alertFormData.alert_channel === '') {
      obj['alert_channel'] = 'Enter Channel';
    }
    setError(obj);
    if (error.alert_channel === '') {
      if (path[2] === 'edit') {
        dispatch(updateKpiAlert(kpiId, alertFormData));
      } else {
        dispatch(createKpiAlert(alertFormData));
      }
    }
  };

  const editableStatus = (type) => {
    var status = '';
    kpiAlertMetaInfo &&
      kpiAlertMetaInfo.length !== 0 &&
      kpiAlertMetaInfo.fields.find((field) => {
        if (field.name === type) {
          status =
            field.is_editable && field.is_sensitive
              ? 'sensitive'
              : field.is_editable
              ? 'editable'
              : '';
        }
        return '';
      });
    return status;
  };

  const onSaveInput = (name) => {
    setEnabled({ ...enabled, [name]: true });
  };

  const onCancelInput = (name) => {
    setEnabled({ ...enabled, [name]: true });
    setSensitveData({ ...sensitiveData, [name]: '' });
  };

  const editAndSaveButton = (name) => {
    return (
      <>
        {enabled[name] ? (
          <button
            className="btn black-button"
            onClick={() => setEnabled({ ...enabled, [name]: false })}>
            <img src={Edit} alt="Edit" />
            <span>Edit</span>
          </button>
        ) : (
          <>
            <button
              className="btn black-button"
              onClick={() => onSaveInput(name)}>
              <span>Save</span>
            </button>
            <button
              className="btn black-secondary-button"
              onClick={() => onCancelInput(name)}>
              <span>Cancel</span>
            </button>
          </>
        )}
      </>
    );
  };

  return (
    <>
      <div className="form-group">
        <h5>Alert Destination</h5>
      </div>
      <div className="form-group">
        <label>Select Channel *</label>
        <div className="editable-field">
          <Select
            options={option}
            classNamePrefix="selectcategory"
            placeholder="Select"
            components={{ SingleValue: customSingleValue }}
            isDisabled={
              path[2] === 'edit'
                ? editableStatus('alert_channel') === 'editable'
                  ? false
                  : editableStatus('alert_channel') === 'sensitive'
                  ? enabled.alert_channel
                  : true
                : false
            }
            value={
              enabled.alert_channel
                ? alertFormData.alert_channel
                  ? {
                      label: (
                        <div className="optionlabel">
                          <img
                            src={
                              alertFormData.alert_channel === 'email'
                                ? Email
                                : Slack
                            }
                            alt="datasource"
                          />
                          {alertFormData.alert_channel}
                        </div>
                      ),
                      value: `${alertFormData.alert_channel}`
                    }
                  : 'none'
                : sensitiveData.alert_channel
            }
            onChange={(e) => {
              setAlertFormData({ ...alertFormData, alert_channel: e.value });
              setField(e.value);
              setError({ ...error, alert_channel: '' });
            }}
          />
        </div>
        <div className="channel-tip">
          <p>
            Tip: Go to{' '}
            <Link to="/alerts/channelconfiguration">Channel configuration</Link>{' '}
            to connect channel
          </p>
          {path[2] === 'edit' &&
            editableStatus('alert_channnel') === 'sensitive' &&
            editAndSaveButton('alert_channel')}
        </div>
        {error.alert_channel && (
          <div className="connection__fail">
            <p>{error.alert_channel}</p>
          </div>
        )}
      </div>
      {field === 'email' ? (
        <div className="form-group">
          <label>Add Recepients </label>
          <div className="editable-field">
            <TagsInput
              value={resp}
              inputProps={{
                className: 'react-tagsinput-input',
                placeholder: 'Add Recepients'
              }}
              onChange={(e) => handleChange(e, 'email')}
              validationRegex={EMAIL_REGEX}
              onValidationReject={() =>
                customToast({
                  type: 'error',
                  header: 'Invalid Email',
                  description: 'Please enter a valid email ID'
                })
              }
            />
          </div>
        </div>
      ) : field === 'slack' ? (
        <div className="form-group">
          <label>Channel name</label>
          <div className="editable-field">
            <input
              type="text"
              className="form-control"
              placeholder="Channel Name"
              disabled={true}
              value={channelName}
            />
          </div>
        </div>
      ) : (
        ''
      )}
      {/* commented add another channel*/}
      {/*Add empty space div*/}
      <div className="add-options-wrapper options-spacing"></div>
      <div className="form-action alerts-button">
        <button className="btn white-button" onClick={() => onBack()}>
          <span>Back</span>
        </button>
        <button
          className={
            createKpiAlertLoading || updateKpiAlertLoading
              ? 'btn black-button btn-loading'
              : 'btn black-button'
          }
          onClick={() => onSubmit()}>
          <div className="btn-spinner">
            <div className="spinner-border" role="status">
              <span className="visually-hidden">Loading...</span>
            </div>
            <span>Loading...</span>
          </div>
          <div className="btn-content">
            <span>{path[2] === 'edit' ? 'Save changes' : 'Add Alert'} </span>
          </div>
        </button>
      </div>
    </>
  );
};

export default EventAlertDestinationForm;
